@@ -24,39 +24,25 @@
  * Author: Daniel Stone <daniel@fooishbar.org>
  */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <ctype.h>
 #include <errno.h>
-#include <unistd.h>
+#ifdef _MSC_VER
+# include <direct.h>
+# include <io.h>
+# ifndef S_ISDIR
+#  define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
+# endif
+#else
+# include <unistd.h>
+#endif
 
 #include "xkbcommon/xkbcommon.h"
 #include "utils.h"
 #include "context.h"
 
-struct xkb_context {
-    int refcnt;
-
-    ATTR_PRINTF(3, 0) void (*log_fn)(struct xkb_context *ctx,
-                                     enum xkb_log_level level,
-                                     const char *fmt, va_list args);
-    enum xkb_log_level log_level;
-    int log_verbosity;
-    void *user_data;
-
-    darray(char *) includes;
-    darray(char *) failed_includes;
-
-    /* xkbcomp needs to assign sequential IDs to XkbFile's it creates. */
-    unsigned file_id;
-
-    struct atom_table *atom_table;
-
-    /* Buffer for the *Text() functions. */
-    char text_buffer[1024];
-    size_t text_next;
-};
-
 /**
  * Append one directory to the context's include path.
  */
@@ -93,27 +79,52 @@ err:
     return 0;
 }
 
+const char *
+xkb_context_include_path_get_system_path(struct xkb_context *ctx)
+{
+    const char *root = secure_getenv("XKB_CONFIG_ROOT");
+    return root ? root : DFLT_XKB_CONFIG_ROOT;
+}
+
 /**
  * Append the default include directories to the context.
  */
 XKB_EXPORT int
 xkb_context_include_path_append_default(struct xkb_context *ctx)
 {
-    const char *home;
+    const char *home, *xdg, *root;
     char *user_path;
     int err;
     int ret = 0;
 
-    ret |= xkb_context_include_path_append(ctx, DFLT_XKB_CONFIG_ROOT);
+    home = secure_getenv("HOME");
 
-    home = getenv("HOME");
-    if (!home)
-        return ret;
-    err = asprintf(&user_path, "%s/.xkb", home);
-    if (err <= 0)
-        return ret;
-    ret |= xkb_context_include_path_append(ctx, user_path);
-    free(user_path);
+    xdg = secure_getenv("XDG_CONFIG_HOME");
+    if (xdg != NULL) {
+        err = asprintf(&user_path, "%s/xkb", xdg);
+        if (err >= 0) {
+            ret |= xkb_context_include_path_append(ctx, user_path);
+            free(user_path);
+        }
+    } else if (home != NULL) {
+        /* XDG_CONFIG_HOME fallback is $HOME/.config/ */
+        err = asprintf(&user_path, "%s/.config/xkb", home);
+        if (err >= 0) {
+            ret |= xkb_context_include_path_append(ctx, user_path);
+            free(user_path);
+        }
+    }
+
+    if (home != NULL) {
+        err = asprintf(&user_path, "%s/.xkb", home);
+        if (err >= 0) {
+            ret |= xkb_context_include_path_append(ctx, user_path);
+            free(user_path);
+        }
+    }
+
+    root = xkb_context_include_path_get_system_path(ctx);
+    ret |= xkb_context_include_path_append(ctx, root);
 
     return ret;
 }
@@ -154,12 +165,6 @@ xkb_context_num_include_paths(struct xkb_context *ctx)
     return darray_size(ctx->includes);
 }
 
-unsigned int
-xkb_context_num_failed_include_paths(struct xkb_context *ctx)
-{
-    return darray_size(ctx->failed_includes);
-}
-
 /**
  * Returns the given entry in the context's include path, or NULL if an
  * invalid index is passed.
@@ -173,22 +178,6 @@ xkb_context_include_path_get(struct xkb_context *ctx, unsigned int idx)
     return darray_item(ctx->includes, idx);
 }
 
-const char *
-xkb_context_failed_include_path_get(struct xkb_context *ctx,
-                                    unsigned int idx)
-{
-    if (idx >= xkb_context_num_failed_include_paths(ctx))
-        return NULL;
-
-    return darray_item(ctx->failed_includes, idx);
-}
-
-unsigned
-xkb_context_take_file_id(struct xkb_context *ctx)
-{
-    return ctx->file_id++;
-}
-
 /**
  * Take a new reference on the context.
  */
@@ -206,7 +195,7 @@ xkb_context_ref(struct xkb_context *ctx)
 XKB_EXPORT void
 xkb_context_unref(struct xkb_context *ctx)
 {
-    if (--ctx->refcnt > 0)
+    if (!ctx || --ctx->refcnt > 0)
         return;
 
     xkb_context_include_path_clear(ctx);
@@ -219,15 +208,15 @@ log_level_to_prefix(enum xkb_log_level level)
 {
     switch (level) {
     case XKB_LOG_LEVEL_DEBUG:
-        return "Debug:";
+        return "xkbcommon: DEBUG: ";
     case XKB_LOG_LEVEL_INFO:
-        return "Info:";
+        return "xkbcommon: INFO: ";
     case XKB_LOG_LEVEL_WARNING:
-        return "Warning:";
+        return "xkbcommon: WARNING: ";
     case XKB_LOG_LEVEL_ERROR:
-        return "Error:";
+        return "xkbcommon: ERROR: ";
     case XKB_LOG_LEVEL_CRITICAL:
-        return "Critical:";
+        return "xkbcommon: CRITICAL: ";
     default:
         return NULL;
     }
@@ -240,7 +229,7 @@ default_log_fn(struct xkb_context *ctx, enum xkb_log_level level,
     const char *prefix = log_level_to_prefix(level);
 
     if (prefix)
-        fprintf(stderr, "%-10s", prefix);
+        fprintf(stderr, "%s", prefix);
     vfprintf(stderr, fmt, args);
 }
 
@@ -251,7 +240,7 @@ log_level(const char *level) {
 
     errno = 0;
     lvl = strtol(level, &endptr, 10);
-    if (errno == 0 && (endptr[0] == '\0' || isspace(endptr[0])))
+    if (errno == 0 && (endptr[0] == '\0' || is_space(endptr[0])))
         return lvl;
     if (istreq_prefix("crit", level))
         return XKB_LOG_LEVEL_CRITICAL;
@@ -298,11 +287,11 @@ xkb_context_new(enum xkb_context_flags flags)
     ctx->log_verbosity = 0;
 
     /* Environment overwrites defaults. */
-    env = getenv("XKB_LOG_LEVEL");
+    env = secure_getenv("XKB_LOG_LEVEL");
     if (env)
         xkb_context_set_log_level(ctx, log_level(env));
 
-    env = getenv("XKB_LOG_VERBOSITY");
+    env = secure_getenv("XKB_LOG_VERBOSITY");
     if (env)
         xkb_context_set_log_verbosity(ctx, log_verbosity(env));
 
@@ -314,6 +303,8 @@ xkb_context_new(enum xkb_context_flags flags)
         return NULL;
     }
 
+    ctx->use_environment_names = !(flags & XKB_CONTEXT_NO_ENVIRONMENT_NAMES);
+
     ctx->atom_table = atom_table_new();
     if (!ctx->atom_table) {
         xkb_context_unref(ctx);
@@ -323,47 +314,6 @@ xkb_context_new(enum xkb_context_flags flags)
     return ctx;
 }
 
-xkb_atom_t
-xkb_atom_lookup(struct xkb_context *ctx, const char *string)
-{
-    return atom_lookup(ctx->atom_table, string);
-}
-
-xkb_atom_t
-xkb_atom_intern(struct xkb_context *ctx, const char *string)
-{
-    return atom_intern(ctx->atom_table, string, false);
-}
-
-xkb_atom_t
-xkb_atom_steal(struct xkb_context *ctx, char *string)
-{
-    return atom_intern(ctx->atom_table, string, true);
-}
-
-char *
-xkb_atom_strdup(struct xkb_context *ctx, xkb_atom_t atom)
-{
-    return atom_strdup(ctx->atom_table, atom);
-}
-
-const char *
-xkb_atom_text(struct xkb_context *ctx, xkb_atom_t atom)
-{
-    return atom_text(ctx->atom_table, atom);
-}
-
-void
-xkb_log(struct xkb_context *ctx, enum xkb_log_level level,
-        const char *fmt, ...)
-{
-    va_list args;
-
-    va_start(args, fmt);
-    ctx->log_fn(ctx, level, fmt, args);
-    va_end(args);
-}
-
 XKB_EXPORT void
 xkb_context_set_log_fn(struct xkb_context *ctx,
                        void (*log_fn)(struct xkb_context *ctx,
@@ -410,20 +360,3 @@ xkb_context_set_user_data(struct xkb_context *ctx, void *user_data)
 {
     ctx->user_data = user_data;
 }
-
-char *
-xkb_context_get_buffer(struct xkb_context *ctx, size_t size)
-{
-    char *rtrn;
-
-    if (size >= sizeof(ctx->text_buffer))
-        return NULL;
-
-    if (sizeof(ctx->text_buffer) - ctx->text_next <= size)
-        ctx->text_next = 0;
-
-    rtrn = &ctx->text_buffer[ctx->text_next];
-    ctx->text_next += size;
-
-    return rtrn;
-}
