@@ -47,6 +47,8 @@
  * DEALINGS IN THE SOFTWARE.
  */
 
+#include "config.h"
+
 #include <errno.h>
 #include <limits.h>
 #include <stdio.h>
@@ -231,7 +233,7 @@ FindFileInXkbPath(struct xkb_context *ctx, const char *name,
             continue;
         }
 
-        file = fopen(buf, "r");
+        file = fopen(buf, "rb");
         if (file)
             break;
     }
